API Reference
=============

QPoint Class
------------

The base class for computing boresight and offset astronomical pointing.

.. autoclass:: qpoint.qpoint_class.QPoint
    :members:
    :undoc-members:
    :show-inheritance:

QMap Class
----------

The class for projecting time-ordered data onto maps and vice-versa.

.. autoclass:: qpoint.qmap_class.QMap
    :members:
    :undoc-members:
    :show-inheritance:

Tools
-----

Other tools used for testing and argument checks.

.. autofunction:: qpoint.version

.. automodule:: qpoint.qpoint_class
    :members: check_input, check_inputs, check_output
    :undoc-members:
    :show-inheritance:

.. automodule:: qpoint.qmap_class
    :members: check_map, check_proj
    :undoc-members:
    :show-inheritance:

.. automodule:: qpoint.tools
    :members:
    :undoc-members:
    :show-inheritance:
